#' Global Variables
#'
#' This block declares global variables to avoid R CMD check warnings.
#'
#' @name globalVariables
#' @title Global Variables Declaration
#' @keywords internal
utils::globalVariables(c("motif", "start", "ID", "length", "seq_order", "end", "name", 
                         "class", "class.x", "support", "x", "y", "yend", "Group","frequency",
                         "element", "value"
                         ))
